==> ws-v3.70.7-src.tar.gz: ws-v3.70-7/include/WSDimage.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDIMAGE_H
#define WSDIMAGE_H

#include <WScom.h>
#include <WSDres.h>

class WSDimage :public WSDres{

  protected:
    WSCushort  _w;
    WSCushort  _h;

  public:
    WSDimage();
    virtual ~WSDimage();
    long destroyImage();

    long setImageName(char* iname); 
    long setImageWidth(WSCushort );
    long setImageHeight(WSCushort );

    WSCushort getImageWidth();
    WSCushort getImageHeight();
    WSCbool   getReady();

    WSMFclassDef(WSDimage,WSDres);
};
#endif //WSDIMAGE_H

==> ws-v3.80.1-src.tar.gz: ws-v3.80-1/include/WSDimage.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDIMAGE_H
#define WSDIMAGE_H

#include <WScom.h>
#include <WSDres.h>

class WSDimage :public WSDres{

  protected:
    WSCushort  _w;
    WSCushort  _h;
    WSCulong       _mode;
  public:
    WSDimage();
    virtual ~WSDimage();
    long destroyImage();

    long setImageName(char* iname); 
    long setImageWidth(WSCushort );
    long setImageHeight(WSCushort );

    WSCushort getImageWidth();
    WSCushort getImageHeight();
    WSCbool   getReady();
    void   setImageMode(WSCulong);
    WSCulong   getImageMode();

    WSMFclassDef(WSDimage,WSDres);
};
#define WS_IMAGE_MODE_REUSE_MEM 0x00000001

#endif //WSDIMAGE_H
